@@ -9,6 +9,8 @@ class ALSA(IntervalModule):
     Requires pyalsaaudio
     """
 
+    interval = 1
+
     settings = (
         ("format", "{volume} is the current volume, {muted} is one of `muted` or `unmuted`. {card} is the sound card used; {mixer} the mixer."),
         ("mixer", "ALSA mixer"),
@@ -52,3 +54,7 @@ class ALSA(IntervalModule):
             "full_text" : self.format.format(**self.fdict),
             "color": self.color_muted if muted else self.color,
         }
+
+    def on_leftclick(self):
+        import subprocess
+        subprocess.Popen(["kmix"])
\ No newline at end of file
