@@ -45,21 +45,21 @@ class Network(IntervalModule):
     Requires the PyPI package `netifaces-py3`.
 
     Available formatters:
-    * {inteface} same as setting
-    * {name} same as setting
-    * {v4} IPv4 address
-    * {v4mask} subnet mask
-    * {v4cidr} IPv4 address in cidr notation (i.e. 192.168.2.204/24)
-    * {v6} IPv6 address
-    * {v6mask} subnet mask
-    * {v6cidr} IPv6 address in cidr notation
-    * {mac} MAC of interface
+    * `{interface}` same as setting
+    * `{name}` same as setting
+    * `{v4}` IPv4 address
+    * `{v4mask}` subnet mask
+    * `{v4cidr}` IPv4 address in cidr notation (i.e. 192.168.2.204/24)
+    * `{v6}` IPv6 address
+    * `{v6mask}` subnet mask
+    * `{v6cidr}` IPv6 address in cidr notation
+    * `{mac}` MAC of interface
 
     Not available addresses (i.e. no IPv6 connectivity) are replaced with empty strings.
     """
 
     settings = (
-        ("interface", "Interface to obtain information for, i.e. eth0"),
+        ("interface", "Interface to obtain information for"),
         "format_up", "color_up",
         "format_down", "color_down",
         "name",
